<?xml version="1.0" ?><!DOCTYPE TS><TS language="nb" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er gratis programvare men utviklingen tar dyrebar tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Vennligst &lt;a href=&apos;%1&apos;&gt;doner&lt;/a&gt; for å støtte videre utvikling av %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Utgitt under &lt;a href=&apos;%1&apos;&gt; GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Hva du alltid ville vite om %1 men ikke turde å spørre om</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>kjøp hos %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Les mer</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Les mer</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tilbake</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Gå tilbake</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velkommen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 trenger å skanne musikksamlingen din.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryte</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Bruk iTunes samling</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Bruk %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Velg en mappe...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 vil koble til Last.fm web-tjenester og sende artister og album titler for å hente cover kunst, biografier og mye mer.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Hvis du har bekymringer for personvernet angående dette kan du avslutte nå.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Hvor er din musikksamling?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Velg plasseringen av din musikksamling.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Lokaliser samlingen din</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tøm</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>En skanning oppgave er allerede i gang</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 skanner din musikksamling. </translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 bruker &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; til å katalogisere musikken.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Dette vil ta tid avhengig av størrelsen på samlingen din og hastigheten for nettverket.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Gå  og hent litt kaffe</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use Demo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Kjøp fullversjonen</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Slipp her for å legge til i spillelisten.</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artister</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Mapper</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Spill av</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Spill av/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stopp avspilling etter gjeldende spor</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Neste spor</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Forrige spor</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Øk volumet</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Senk volumet</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Demp lyden</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Søk fremover</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Søk bakover</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tilbake</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Gå til forrige visning</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Vis informasjon om gjeldende spor</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>F&amp;orrige</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Gå til forrige spor</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Neste</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Hopp til neste spor</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spill av</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Start avspilling</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Full Skjerm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Gå full skjerm</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Fjern de valgte sporene fra spillelisten</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;Opp</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Flytt opp de valgte sporene i spillelisten</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;Ned</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Flytt ned de valgte sporene i spillelisten</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Farvel</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Forandre samlingsmappe...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Velg en annen musikksamling mappe</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Hjemmeside</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på nettet</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Gjør en &amp;donasjon</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Vennligst støtt den fortsatte utvikling av %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info om %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Tøm</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Fjern alle sporene fra spillelisten</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Blande</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Blandet spilleliste modus</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Gjenta</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Spill første sangen på nytt etter at alle sangene er ferdigspilt</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Demp lyden</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Applikasjon</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Avspilling</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Spille&amp;liste</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visning</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Trykk %1 for å øke lyden, %2 for å senke den</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Åpner %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Oppdaterer samlingen...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Oppdaterer samlingen - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Samlingen er oppdatert</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Fatal feil: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feil: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Forlat &amp;Full Skjerm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Gjenværende tid: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Lyden er %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Lyden er dempet</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Demping av lyd fjernet</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Kjøp fullversjonen</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Steng</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Slipp elementer her</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Spillelisten ferdig</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Dette er bare demoversjonen av %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Den lar deg spille et par låter, slik at du kan teste programmet og se om det fungerer for deg.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsett</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Få den fulle versjonen</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Spillelisten er tom</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 spor - Total lengde er %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Spor</translation>
    </message>
</context>
</TS>